@@ -63,7 +63,11 @@ def get_predicted_strandedness(forward_evidence_pct, reverse_evidence_pct):
     predicted = "Inconclusive"
     if 0.4 <= forward_evidence_pct and forward_evidence_pct <= 0.6:
         predicted = "Unstranded"
-    if 0.8 <= forward_evidence_pct:
+    # This second Unstranded check is redundant with the first check,
+    # but more explicit
+    elif 0.4 <= reverse_evidence_pct and reverse_evidence_pct <= 0.6:
+        predicted = "Unstranded"
+    elif 0.8 <= forward_evidence_pct:
         predicted = "Stranded-Forward"
     elif 0.8 <= reverse_evidence_pct:
         predicted = "Stranded-Reverse"
@@ -79,6 +83,8 @@ def determine_strandedness(
     minimum_reads_per_gene=10,
     split_by_rg=False,
     max_iterations_per_try=1000,
+    checked_genes=set(),
+    overall_evidence=defaultdict(lambda: defaultdict(int)),
 ):
     try:
         ngsfile = NGSFile(ngsfilepath)
@@ -112,11 +118,6 @@ def determine_strandedness(
     if "RG" in samfile.header:
         read_groups += [rg["ID"] for rg in samfile.header["RG"]]
 
-    overall_evidence = defaultdict(dict)
-
-    for rg in read_groups:
-        overall_evidence[rg] = defaultdict(int)
-
     logger.debug("Starting sampling...")
     total_iterations = 0
     while True:
@@ -134,6 +135,7 @@ def determine_strandedness(
             continue
 
         if disqualify_gene(gene, gff, samfile):
+            checked_genes.add(gene["gene_id"])
             continue
 
         logging.debug("== Candidate Gene ==")
@@ -247,7 +249,7 @@ def determine_strandedness(
                     "Predicted": predicted,
                 }
             )
-        return results
+        return (results, checked_genes, overall_evidence)
     else:
         evidence_stranded_forward = 0
         evidence_stranded_reverse = 0
@@ -265,7 +267,6 @@ def determine_strandedness(
                 + overall_evidence[rg]["2++"]
                 + overall_evidence[rg]["2--"]
             )
-
         total_reads = evidence_stranded_forward + evidence_stranded_reverse
         forward_pct = (
             0 if total_reads <= 0 else round(evidence_stranded_forward / total_reads, 4)
@@ -275,15 +276,19 @@ def determine_strandedness(
         )
         predicted = get_predicted_strandedness(forward_pct, reverse_pct)
 
-        return [
-            {
-                "File": ngsfilepath,
-                "TotalReads": total_reads,
-                "ForwardPct": forward_pct,
-                "ReversePct": reverse_pct,
-                "Predicted": predicted,
-            }
-        ]
+        return (
+            [
+                {
+                    "File": ngsfilepath,
+                    "TotalReads": total_reads,
+                    "ForwardPct": forward_pct,
+                    "ReversePct": reverse_pct,
+                    "Predicted": predicted,
+                }
+            ],
+            checked_genes,
+            overall_evidence,
+        )
 
 
 def main(
@@ -336,12 +341,14 @@ def main(
 
     for ngsfilepath in ngsfiles:
         tries_for_file = 0
+        checked_genes = set()
+        overall_evidence = defaultdict(lambda: defaultdict(int))
 
         while True:
             tries_for_file += 1
             logger.info("Processing {}, try #{}...".format(ngsfilepath, tries_for_file))
 
-            entries = determine_strandedness(
+            entries, checked_genes, overall_evidence = determine_strandedness(
                 ngsfilepath,
                 gff,
                 n_genes=n_genes,
@@ -349,6 +356,8 @@ def main(
                 minimum_reads_per_gene=minimum_reads_per_gene,
                 split_by_rg=split_by_rg,
                 max_iterations_per_try=max_iterations_per_try,
+                checked_genes=checked_genes,
+                overall_evidence=overall_evidence,
             )
 
             entries_contains_inconclusive = False
